.. _api:

#################
API documentation
#################

:Release: |version|
:Date: |today|


.. currentmodule:: sisl

This reference manual describes in detail how the modules, classes
and functions can be used and how their API's are defined.

These documents are complemented with the sisl tutorial.

All methods and submodules are listed  :ref:`here <genindex>` and
:ref:`here <modindex>`, respectively.

.. toctree::
   :maxdepth: 2

   basic
   geom/building
   geom/neighbors
   physics
   mixing
   viz/index
   unit_constant
   utilities

.. toctree::
   :maxdepth: 1

   core
   io/index

.. toctree::
   :maxdepth: 1
   :caption: Advanced usage

   typing
